==> web-9.0.0.tgz: package/lib/toast/index.js <==
import * as React from "react";
import * as Immutable from "immutable";
import * as ReactDom from "react-dom";
import { Animate } from "../animate/index";
import { SvgIcon } from "../my-icon/index";
class Notice extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            messages: Immutable.List([]),
        };
        this.add = (obj) => {
            this.setState(pre => {
                return {
                    messages: pre.messages.push(obj),
                };
            });
        };
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const id = dom.dataset.id;
            this.remove(id);
        };
        this.remove = (id) => {
            this.setState(pre => {
                return {
                    messages: pre.messages.filter(val => {
                        return val.id !== id;
                    })
                };
            });
        };
        this.clear = () => {
            const { messages } = this.state;
            if (!messages.size) {
                return;
            }
            this.setState(pre => {
                pre.messages.forEach(val => {
                    const { timerId } = val;
                    if (timerId) {
                        window.clearTimeout(timerId);
                    }
                });
                return {
                    messages: pre.messages.clear(),
                };
            });
        };
    }
    render() {
        const { messages } = this.state;
        const list = messages.map(val => {
            const { id, text, type } = val;
            return (React.createElement(Animate, { key: id, animation: "bounceRightIn", duration: 400, runMount: true },
                React.createElement("span", { className: `g-alertInfo ${type}` },
                    React.createElement("span", null,
                        React.createElement("span", { className: `notice-item` },
                            React.createElement(SvgIcon, { className: type, size: "middle" })),
                        React.createElement("span", { className: "txt" }, text)),
                    React.createElement("span", { className: "m-alert-close", "data-id": id, onClick: this.clickFn },
                        React.createElement(SvgIcon, { className: "close" })))));
        });
        return (React.createElement("div", { className: "g-notification" }, list));
    }
}
let noticeRef = null;
let noticeCount = 0;
const createTimekey = function () {
    return ++noticeCount;
};
const fn = (ref) => {
    noticeRef = ref;
};
const createNotice = function (callback) {
    const wrap = document.getElementById("wrap-notice");
    if (!wrap) {
        throw new Error("不存在notice组件的容器，请生成id为 wrap-notice的div");
    }
    ReactDom.render(React.createElement(Notice, { ref: fn }), wrap, function () {
        if (callback) {
            callback();
        }
    });
};
const addFn = function (messages, keep) {
    let timerId;
    if (!keep) {
        timerId = window.setTimeout(function () {
            noticeRef.remove(messages.id);
        }, 2000);
        messages.timerId = timerId;
    }
    noticeRef.add(messages);
};
const notice = {
    add: function (text, type = "success", keep) {
        const id = `${createTimekey()}`;
        const obj = {
            id,
            type,
            text,
        };
        if (!noticeRef) {
            createNotice(function () {
                addFn(obj, keep);
            });
        }
        else {
            addFn(obj, keep);
        }
    },
    clear: function () {
        if (noticeRef) {
            noticeRef.clear();
        }
    },
};
export { createNotice };
export default notice;

==> web-11.0.2.tgz: package/lib/toast/index.js <==
import * as React from "react";
import * as Immutable from "immutable";
import * as ReactDom from "react-dom";
import { Animate } from "../animate/index";
import { SvgIcon } from "../my-icon/index";
class Notice extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            messages: Immutable.List([]),
        };
        this.add = (obj) => {
            this.setState((pre) => ({
                messages: pre.messages.push(obj),
            }));
        };
        this.clickFn = (e) => {
            const dom = e.currentTarget;
            const id = dom.dataset.id;
            this.remove(id);
        };
        this.remove = (id) => {
            this.setState((pre) => ({
                messages: pre.messages.filter((val) => val.id !== id)
            }));
        };
        this.clear = () => {
            const { messages } = this.state;
            if (!messages.size) {
                return;
            }
            this.setState((pre) => {
                pre.messages.forEach((val) => {
                    const { timerId } = val;
                    if (timerId) {
                        window.clearTimeout(timerId);
                    }
                });
                return {
                    messages: pre.messages.clear(),
                };
            });
        };
    }
    render() {
        const { messages } = this.state;
        const list = messages.map((val) => {
            const { id, text, type } = val;
            return (React.createElement(Animate, { key: id, animation: "bounceRightIn", duration: 400, runMount: true },
                React.createElement("span", { className: `g-alertInfo ${type}` },
                    React.createElement("span", null,
                        React.createElement("span", { className: `notice-item` },
                            React.createElement(SvgIcon, { className: type, size: "middle" })),
                        React.createElement("span", { className: "txt" }, text)),
                    React.createElement("span", { className: "m-alert-close", "data-id": id, onClick: this.clickFn },
                        React.createElement(SvgIcon, { className: "close" })))));
        });
        return (React.createElement("div", { className: "g-notification" }, list));
    }
}
let noticeRef = null;
let noticeCount = 0;
const createTimekey = function () {
    return ++noticeCount;
};
const fn = (ref) => {
    noticeRef = ref;
};
const createNotice = function (callback) {
    const wrap = document.getElementById("wrap-notice");
    if (!wrap) {
        throw new Error("不存在notice组件的容器，请生成id为 wrap-notice的div");
    }
    ReactDom.render(React.createElement(Notice, { ref: fn }), wrap, function () {
        if (callback) {
            callback();
        }
    });
};
const addFn = function (messages, keep) {
    let timerId;
    if (!keep) {
        timerId = window.setTimeout(function () {
            noticeRef.remove(messages.id);
        }, 2000);
        messages.timerId = timerId;
    }
    noticeRef.add(messages);
};
const notice = {
    add: function (text, type = "success", keep) {
        const id = `${createTimekey()}`;
        const obj = {
            id,
            type,
            text,
        };
        if (!noticeRef) {
            createNotice(function () {
                addFn(obj, keep);
            });
        }
        else {
            addFn(obj, keep);
        }
    },
    clear: function () {
        if (noticeRef) {
            noticeRef.clear();
        }
    },
};
export { createNotice };
export default notice;
